# Aliens on My Lawn
# Copyright (C) 2009 Jeffrey Armstrong (a.k.a. PrintStar)
# http://jeff.rainbow-100.com/
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# A full version of the license terms is available in LICENSE.

from pygame import *
from data import *
from constants import *

class BaseSprite(sprite.Sprite):
    def __init__(self):
        sprite.Sprite.__init__(self)
        
        self.image_index = 0
        self.moves_this_round = 0
        self.direction = SOUTH
        self.animate_index = 0
        self.velocity = 5
        
        self.initialize_images()
        self.rect = Rect(0,0,GRID_X,GRID_Y)
        
    def initialize_images(self):
        self.image_index = 0
        self.image_directions = []
        self.load_images()
        self.image = None
        self.set_image(init=True)
    
    def load_images(self):
        for i in range(0,4):
            onedir = []
            for x in self.image_filenames(i):
                onedir.append(load_image(x))
            self.image_directions.append(onedir)
    
    def can_move(self):
        return True
        
    def north(self,blockers=None):
        self.moves_this_round = self.moves_this_round + 1
        if self.can_move():
            self.rect.top = self.rect.top - self.velocity
            self.direction = NORTH
            if blockers != None:
                hits = sprite.spritecollide(self,blockers,False)
                if len(hits) > 0:
                    self.rect.top = hits[0].rect.bottom 
    
    def south(self,blockers=None):
        self.moves_this_round = self.moves_this_round + 1
        if self.can_move():
            self.rect.top = self.rect.top + self.velocity
            self.direction = SOUTH
            if blockers != None:
                hits = sprite.spritecollide(self,blockers,False)
                if len(hits) > 0:
                    self.rect.bottom = hits[0].rect.top
    
    def east(self,blockers=None):
        self.moves_this_round = self.moves_this_round + 1
        if self.can_move():
            self.rect.left = self.rect.left + self.velocity
            self.direction = EAST
            if blockers != None:
                hits = sprite.spritecollide(self,blockers,False)
                if len(hits) > 0:
                    self.rect.right = hits[0].rect.left
    
    def west(self,blockers=None):
        self.moves_this_round = self.moves_this_round + 1
        if self.can_move():
            self.rect.left = self.rect.left - self.velocity
            self.direction = WEST
            if blockers != None:
                hits = sprite.spritecollide(self,blockers,False)
                if len(hits) > 0:
                    self.rect.left = hits[0].rect.right
    
    def move_all_directions(self,directions,blockers=None):
        for i in range(0,4):
            if directions[i]:
                self.move(i,blockers)
    
    def move(self,direction,blockers=None):
        if direction == NORTH:
            self.north(blockers)
        elif direction == SOUTH:
            self.south(blockers)
        elif direction == EAST:
            self.east(blockers)
        elif direction == WEST:
            self.west(blockers)
        
    def set_image(self,init=False):
        if self.moves_this_round == 0 and not init: # Don't change image if hasn't moved
            return
        
        images = self.image_directions[self.direction]
        
        self.image_index = self.image_index + 1
        if self.image_index >= len(images):
            self.image_index = 0
            
        self.image = images[self.image_index]
        
    def update(self):
        self.set_image()
        self.moves_this_round = 0
