# Aliens on My Lawn
# Copyright (C) 2009 Jeffrey Armstrong (a.k.a. PrintStar)
# http://jeff.rainbow-100.com/
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# A full version of the license terms is available in LICENSE.

from constants import *
from pygame import *

from data import filepath, load_image

MENU_IMAGE = 'menu.png'
DEAD_IMAGE = 'grave.png'
MESSAGE_FONT = 'primeministerofcanada.ttf'

class FullScreenSprite(sprite.Sprite):
    def __init__(self, image, width=SCR_WIDTH, height=SCR_HEIGHT):
        sprite.Sprite.__init__(self)
        
        self.rect = Rect(0,0,width,height)
        self.image = image
        

class MessageSprite(FullScreenSprite):
    def __init__(self, image, width=SCR_WIDTH, height=SCR_HEIGHT):
        FullScreenSprite.__init__(self,image,width,height)
        
        text_font = font.Font(filepath(MESSAGE_FONT),18)
        spr = text_font.render('Press SPACE to continue...',1,Color('black'))
        
        bkgd = Surface((spr.get_width()+50,spr.get_height()+20))
        bkgd.fill(Color('grey'))
        self.image.blit(bkgd,(self.rect.width/2-bkgd.get_width()/2,self.rect.height-34)) 
        
        self.image.blit(spr,(self.rect.width/2-spr.get_width()/2,self.rect.height-24))
        
class DeadSprite(MessageSprite):
    def __init__(self):
        MessageSprite.__init__(self,load_image(DEAD_IMAGE))
        self.base = self.image
        
        self.image = Surface((self.rect.width,self.rect.height))
        #self.image.fill(Color(255,0,0,190))
        self.image.fill(Color('red'))
        
        self.image.blit(self.base,(0,0))
        self.image.set_alpha(190)
        
class MenuSprite(FullScreenSprite):
    def __init__(self, width=SCR_WIDTH, height=SCR_HEIGHT):
        FullScreenSprite.__init__(self,load_image(MENU_IMAGE),width,height)
        self.choice = 0
        self.resume = False
        self.base = self.image
        
    def up(self):
        self.choice = max(self.choice - 1,0)
    
    def down(self):
        self.choice = min(self.choice+1, 1)    
    
    def exit(self):
        return self.choice == 1
    
    def game(self):
        return self.choice == 0
    
    def update(self):
        
        game = 'New Game'
        if self.resume:
            game = 'Resume'
        
        game_color = Color('black')
        exit_color = Color('black')
        if self.choice == 0:
            game_color = Color('red')
        else:
            exit_color = Color('red')
        
        menu_text = font.Font(filepath(MESSAGE_FONT),48)
            
        game_spr = menu_text.render(game,1,game_color)
        exit_spr = menu_text.render('Exit',1,exit_color)
        
        self.image = Surface((self.rect.width,self.rect.height))
        self.image.fill(Color('white'))
        self.image.set_alpha(190)
        self.image.blit(self.base,(0,0))
        self.image.blit(game_spr,(self.rect.width/2 - game_spr.get_width()/2,200))
        self.image.blit(exit_spr,(self.rect.width/2 - exit_spr.get_width()/2,275))
        
        